@@ -20,9 +20,10 @@ Implementation Notes
   https://github.com/adafruit/circuitpython/releases
 
 """
-# pylint: disable=too-many-arguments, too-many-instance-attributes, too-many-locals
+
 # pylint: disable=too-many-statements, unused-import, no-member
 # pylint: disable=unused-import, import-outside-toplevel, undefined-variable
+# pylint: disable=attribute-defined-outside-init
 
 try:
     from typing import Union, Tuple
@@ -36,7 +37,7 @@ from vectorio import Circle
 from ulab import numpy as np
 
 
-__version__ = "0.11.2"
+__version__ = "0.14.0"
 __repo__ = "https://github.com/jposada202020/CircuitPython_uplot.git"
 
 
@@ -131,7 +132,7 @@ class Uplot(displayio.Group):
         if show_box:
             self._drawbox()
 
-        self._plot_palette = displayio.Palette(17)
+        self._plot_palette = displayio.Palette(20)
         self._plot_palette[0] = background_color
         self._plot_palette[1] = box_color
         self._plot_palette[2] = self._tickcolor
@@ -145,7 +146,14 @@ class Uplot(displayio.Group):
         self._plot_palette[10] = 0x64A813
         self._plot_palette[11] = 0x0F4E12
         self._plot_palette[12] = 0xF0075E
-        self._plot_palette[13] = 0x1AF0FF
+        self._plot_palette[13] = 0x123456
+        self._plot_palette[14] = 0xFF00FF
+        self._plot_palette[15] = 0xFF0000
+        self._plot_palette[16] = 0x440044
+        self._plot_palette[17] = 0x2222FF
+        self._plot_palette[18] = 0x1A50FF
+        self._plot_palette[19] = 0xF0FF32
+
         self.append(
             displayio.TileGrid(
                 self._plotbitmap, pixel_shader=self._plot_palette, x=0, y=0
@@ -380,6 +388,8 @@ class Uplot(displayio.Group):
         if self._showtext:
             from adafruit_display_text import bitmap_label
 
+            self.bitmap_label = bitmap_label
+
     def _draw_gridx(self, ticks_data: list[int]) -> None:
         """
         Draws the plot grid
@@ -439,7 +449,7 @@ class Uplot(displayio.Group):
     ) -> None:
         """
 
-        Show desired text in the scree
+        Show desired text in the screen
         :param str text: text to be displayed
         :param int x: x coordinate
         :param int y: y coordinate
@@ -447,7 +457,7 @@ class Uplot(displayio.Group):
         :return: None
         """
         if self._showtext:
-            text_toplot = bitmap_label.Label(terminalio.FONT, text=text, x=x, y=y)
+            text_toplot = self.bitmap_label.Label(terminalio.FONT, text=text, x=x, y=y)
             text_toplot.anchor_point = anchorpoint
             text_toplot.anchored_position = (x, y)
             self.append(text_toplot)
